==> 0.0.4.tar.gz: android/src/main/kotlin/pro/devonics/flutter/push_devonics/PushDevonicsPlugin.kt <==
package pro.devonics.flutter.push_devonics

import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import pro.devonics.push.PushDevonics

/** PushDevonicsPlugin */
class PushDevonicsPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "push_devonics")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "init") {
      val app_id = call.argument<String>("app_id")
      if (app_id != null) {
        pushDevonics = PushDevonics(applicationContext, app_id)
        lifecycle.addObserver(pushDevonics)
      } else {
        result.error("Flutter Push Devonics", "Empty app_id", null)
      }
      //result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> 0.0.6.tar.gz: android/src/main/kotlin/pro/devonics/flutter/push_devonics/PushDevonicsPlugin.kt <==
package pro.devonics.flutter.push_devonics

import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import pro.devonics.push.PushDevonics
import androidx.appcompat.app.AppCompatActivity

/** PushDevonicsPlugin */
class PushDevonicsPlugin: FlutterPlugin, MethodCallHandler, AppCompatActivity() {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var pushDevonics: PushDevonics

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "push_devonics")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "init") {
      val app_id = call.argument<String>("app_id")
      if (app_id != null) {
        pushDevonics = PushDevonics(applicationContext, app_id)
        lifecycle.addObserver(pushDevonics)
      } else {
        result.error("Flutter Push Devonics", "Empty app_id", null)
      }
      //result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
